==> dhall-bash-1.0.41-108-x86_64.pkg.tar.zst: usr/share/haskell/register/dhall-bash.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 dhall-bash
version:              1.0.41
visibility:           public
id:                   dhall-bash-1.0.41-1HBYykzOUa5L5o819vHhzK
key:                  dhall-bash-1.0.41-1HBYykzOUa5L5o819vHhzK
license:              BSD-3-Clause
copyright:            2017 Gabriella Gonzalez
maintainer:           GenuineGabriella@gmail.com
author:               Gabriella Gonzalez
synopsis:             Compile Dhall to Bash
description:
    Use this package if you want to compile Dhall expressions to Bash.
    You can use this package as a library or an executable:

    * See the "Dhall.Bash" module if you want to use this package as a library

    * Use the @dhall-to-bash@ if you want an executable

    The "Dhall.Bash" module also contains instructions for how to use this
    package

category:             Compiler
abi:                  1e3e836b684d8c15aec8ec8b108b1f23
exposed:              True
exposed-modules:      Dhall.Bash
import-dirs:          /usr/lib/ghc-9.4.8/site-local/dhall-bash-1.0.41
library-dirs:         /usr/lib/ghc-9.4.8/site-local/dhall-bash-1.0.41
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/dhall-bash-1.0.41
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/dhall-bash
hs-libraries:         HSdhall-bash-1.0.41-1HBYykzOUa5L5o819vHhzK
depends:
    base-4.17.2.1 bytestring-0.11.5.3 containers-0.6.7
    dhall-1.42.2-87DsYLGRkvc3QarVTsKqYU
    neat-interpolation-0.5.1.4-Cfxywz6AAG0AKQEBSsPPiL
    shell-escape-0.2.0-KV12GVNp7jX10Thz9ZuowO text-2.0.2

haddock-interfaces:   /usr/share/doc/dhall-bash/html/dhall-bash.haddock
haddock-html:         /usr/share/doc/dhall-bash/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> dhall-bash-1.0.41-109-x86_64.pkg.tar.zst: usr/share/haskell/register/dhall-bash.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 dhall-bash
version:              1.0.41
visibility:           public
id:                   dhall-bash-1.0.41-CBIBvS6O7hB2Va3te0knYp
key:                  dhall-bash-1.0.41-CBIBvS6O7hB2Va3te0knYp
license:              BSD-3-Clause
copyright:            2017 Gabriella Gonzalez
maintainer:           GenuineGabriella@gmail.com
author:               Gabriella Gonzalez
synopsis:             Compile Dhall to Bash
description:
    Use this package if you want to compile Dhall expressions to Bash.
    You can use this package as a library or an executable:

    * See the "Dhall.Bash" module if you want to use this package as a library

    * Use the @dhall-to-bash@ if you want an executable

    The "Dhall.Bash" module also contains instructions for how to use this
    package

category:             Compiler
abi:                  1e5ac6b5f1def98a28fb7067485bd6f8
exposed:              True
exposed-modules:      Dhall.Bash
import-dirs:          /usr/lib/ghc-9.4.8/site-local/dhall-bash-1.0.41
library-dirs:         /usr/lib/ghc-9.4.8/site-local/dhall-bash-1.0.41
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/dhall-bash-1.0.41
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/dhall-bash
hs-libraries:         HSdhall-bash-1.0.41-CBIBvS6O7hB2Va3te0knYp
depends:
    base-4.17.2.1 bytestring-0.11.5.3 containers-0.6.7
    dhall-1.42.2-4mAPAMLxy1a63Lj3vZWfJM
    neat-interpolation-0.5.1.4-LYz6WVaiIBtC4khXHLOLRt
    shell-escape-0.2.0-8DsjfOtlNxU6ckwdY7xCS1 text-2.0.2

haddock-interfaces:   /usr/share/doc/dhall-bash/html/dhall-bash.haddock
haddock-html:         /usr/share/doc/dhall-bash/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
